summaryrefslogtreecommitdiffstats
path: root/build.py
diff options
context:
space:
mode:
Diffstat (limited to 'build.py')
-rw-r--r--build.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/build.py b/build.py
index 456f080..c8ecc23 100644
--- a/build.py
+++ b/build.py
@@ -123,7 +123,7 @@ LIBS += @TEST_TQUI_LIB@ @TEST_TQSCINTILLA_LIB@
config.patches["@TEST_TQSCINTILLA_INC@"] = ""
config.patches["@TEST_TQSCINTILLA_LIB@"] = ""
- # Create a dummy source file to suppress a qmake warning.
+ # Create a dummy source file to suppress a tqmake warning.
sip_tqt_config.copy_to_file("tqttest.cpp", "")
config.create_makefile("tqttest.pro")
@@ -573,7 +573,7 @@ def main(argv):
config.patches["@PYTQT_RBPROF@"] = rbprof
# Link in the qassistantclient library for TQt v3.1+.
tqaclib = ""
if config.tqt_version >= 0x030100:
@@ -582,7 +582,7 @@ def main(argv):
else:
tqaclib = "-ltqassistantclient"
- config.patches["@PYTQT_QASSISTANTCLIENT_LIB@"] = tqaclib
+ config.patches["@PYTQT_TQASSISTANTCLIENT_LIB@"] = tqaclib
# Check for TQScintilla.
if config.tqt_version >= 0x030000:
@@ -573,7 +573,7 @@ def main(argv):
config.patches["@PYTQT_RBPROF@"] = rbprof
- # Link in the qassistantclient library for TQt v3.1+.
+ # Link in the tqassistantclient library for TQt v3.1+.
tqaclib = ""
if config.tqt_version >= 0x030100: